@@ -2,8 +2,8 @@
   PROJECT: MusixTeX PreProcessor
   FILE   : version.cc
   AUTHOR : J. C. Nieuwenhuizen
-           tnnvjn@urc.tue.nl
-  copyright (c) FlowerSoft 1995
+           jan@digicash.com
+  copyright (c) FlowerSoft 1995, 1997
 --*/
 
 #include "version.hh"
